@@ -250,7 +250,7 @@ class Arc(Curve):
         if close_circuit:
             raise NotImplementedError(f"Close circuit not implemented for type [{type(self)}]")
 
-        end_point = self.end_point()
+        end_point = self.end_point
         if self.orientation in (Orientation.UP_LEFT, Orientation.DOWN_LEFT) and next_point.x > end_point.x:
             return Vector2(end_point.x, next_point.y)
         elif self.orientation in (Orientation.UP_RIGHT, Orientation.DOWN_RIGHT) and next_point.x < end_point.x:
@@ -297,12 +297,12 @@ class CircularArc(Curve):
             ret = CircularArc(id=naming_provider(),
                               origin=a,
                               destination=c,
-                              center=circle.center)
+                              center=circle.Center)
         else:
             ret = CircularArc(id=naming_provider(),
                               origin=c,
                               destination=a,
-                              center=circle.center)
+                              center=circle.Center)
 
         return ret
 
