@@ -65,6 +65,10 @@ class Circle:
         else:
             return 2 * math.pi + delta
 
+    @property
+    def Center(self):
+        return self.center
+
     def __repr__(self):
         return self.__str__()
 
