@@ -25,8 +25,11 @@ class Line:
             raise TypeError(f"can only intersect with objects of type <Line> but type {type(other_line)} was provided")
 
         try:
-            return geo.line_intersection(line1=(self.origin.as_tuple(), self.destination.as_tuple()),
+            intersect = geo.line_intersection(line1=(self.origin.as_tuple(), self.destination.as_tuple()),
                                      line2=(other_line.origin.as_tuple(), other_line.destination.as_tuple()),
                                      extend=extend)
+
+            return Vector2(intersect[0], intersect[1])
+
         except:
             return None
\ No newline at end of file
