@@ -7,19 +7,31 @@ class Toggleable():
                  values: List,
                  starting_index: int = 0,
                  starting_value: Any = None,
-                 on_toggle_callbacks: List[Callable[[], Any]] = None):
+                 on_toggle_callbacks: List[Callable[[], Any]] = None,
+                 allow_wrap: bool = True):
         # TODO: Values is better as a generator. This allows for user to provide an "infinite" list and not provide all values to memory
         self.values = values
         self.index = 0
         self.on_toggle_callbacks = on_toggle_callbacks
+        self._allow_wrap = allow_wrap
 
         if starting_value and starting_value in values: self.index = self.values.index(starting_value)
         if starting_index and starting_index < len(values): self.index = starting_index
 
-    def toggle(self, on_toggle_callbacks: List[Callable[[Any], Any]] = None):
-        self.index += 1
+    def toggle(self, on_toggle_callbacks: List[Callable[[Any], Any]] = None, reverse: bool = False):
+        if reverse:
+            self.index -= 1
+        else:
+            self.index += 1
 
-        if self.index >= len(self.values):
+        if self.index >= len(self.values) and self._allow_wrap:
+            self.index = 0
+        elif self.index >= len(self.values):
+            self.index = len(self.values) - 1
+
+        if self.index < 0 and self._allow_wrap:
+            self.index = len(self.values) - 1
+        elif self.index < 0:
             self.index = 0
 
         if self.on_toggle_callbacks is not None:
@@ -105,7 +117,8 @@ class IntegerRangeToggleable(Toggleable):
                  max: int,
                  step_size: int = 1,
                  on_toggle_callbacks: List[Callable[[Any], Any]] = None,
-                 starting_value: int = None):
+                 starting_value: int = None,
+                 allow_wrap: bool = True):
         if starting_value and \
                 ((not (min <= starting_value <= max)) or
                  (starting_value - min % step_size != 0)):
@@ -117,7 +130,8 @@ class IntegerRangeToggleable(Toggleable):
         Toggleable.__init__(self,
                             values=[ii for ii in range(min, max + 1, step_size)],
                             on_toggle_callbacks=on_toggle_callbacks,
-                            starting_index=starting_index)
+                            starting_index=starting_index,
+                            allow_wrap=allow_wrap)
 
         self.min = min
         self.max = max
