@@ -7,6 +7,9 @@ class IVector:
     def from_ivector(self, ivec):
         raise NotImplementedError()
 
+    def __copy__(self):
+        raise NotImplementedError()
+
     def __init__(self, coords: Dict = None):
         if coords is not None:
             self.coords = coords
@@ -26,6 +29,24 @@ class IVector:
             new[ii] = 0
         return new
 
+    def with_(self, x: float = None, y: float = None, z: float = None, updates: Dict[str, float] = None):
+
+        cpy = self.__copy__()
+
+        if x is not None:
+            cpy.x = x
+
+        if y is not None:
+            cpy.y = y
+
+        if z is not None:
+            cpy.z = z
+
+        for dim, val in updates.items():
+            cpy[dim] = val
+
+        return cpy
+
     @property
     def x(self):
         return self.coords.get('x', None)
@@ -336,6 +357,9 @@ class Vector2 (IVector):
 
         return Vector2(x, y)
 
+    def __copy__(self):
+        return Vector2(self.x, self.y)
+
     def __init__(self, x: float, y: float):
         IVector.__init__(self)
         self.coords['x'] = x
@@ -367,6 +391,9 @@ class Vector3(IVector):
 
         return Vector3(x, y, z)
 
+    def __copy__(self):
+        return Vector3(self.x, self.y, self.z)
+
     def __init__(self, x: float, y: float, z: float):
         IVector.__init__(self)
         self.coords['x'] = x
